@@ -1,6 +1,6 @@
 package Email::MIME::Kit::KitReader::Dir;
 # ABSTRACT: read kit entries out of a directory
-$Email::MIME::Kit::KitReader::Dir::VERSION = '3.000001';
+$Email::MIME::Kit::KitReader::Dir::VERSION = '3.000002';
 use Moose;
 with 'Email::MIME::Kit::Role::KitReader';
 
@@ -19,6 +19,8 @@ sub get_kit_entry {
   return \$content;
 }
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -33,7 +35,7 @@ Email::MIME::Kit::KitReader::Dir - read kit entries out of a directory
 
 =head1 VERSION
 
-version 3.000001
+version 3.000002
 
 =head1 AUTHOR
 
@@ -41,7 +43,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
